Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2111)

Unified Diff: chrome/browser/nacl_host/pnacl_file_host.h

Issue 12163003: Add FilePath to base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/nacl_host/pnacl_file_host.h
diff --git a/chrome/browser/nacl_host/pnacl_file_host.h b/chrome/browser/nacl_host/pnacl_file_host.h
index 71875610dd4d80e19fe3c78cd99aa06bdb02e46b..f1a31bd9aeb344d1ee0b92a85a764747e280c932 100644
--- a/chrome/browser/nacl_host/pnacl_file_host.h
+++ b/chrome/browser/nacl_host/pnacl_file_host.h
@@ -8,7 +8,10 @@
#include <string>
class ChromeRenderMessageFilter;
+
+namespace base {
class FilePath;
+}
namespace IPC {
class Message;
@@ -24,9 +27,9 @@ void GetReadonlyPnaclFd(ChromeRenderMessageFilter* chrome_render_message_filter,
IPC::Message* reply_msg);
// Return true if the filename requested is valid for opening.
// Sets file_to_open to the FilePath which we will attempt to open.
bool PnaclCanOpenFile(const std::string& filename,
- FilePath* file_to_open);
+ base::FilePath* file_to_open);
// Creates a temporary file that will be deleted when the last handle
// is closed, or earlier.
@@ -24,9 +27,9 @@ void GetReadonlyPnaclFd(ChromeRenderMessageFilter* chrome_render_message_filter,
IPC::Message* reply_msg);
// Return true if the filename requested is valid for opening.
-// Sets file_to_open to the FilePath which we will attempt to open.
+// Sets file_to_open to the base::FilePath which we will attempt to open.
bool PnaclCanOpenFile(const std::string& filename,

Powered by Google App Engine
This is Rietveld 408576698